//                                                                  
// Copyright  2013 Lidor Systems.
// All Rights Reserved.
//
// This SOFTWARE is provided "AS IS", WITHOUT WARRANTY OF ANY KIND.
// either express or implied.                        
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Text;
using System.Windows.Forms;

namespace IntegralUI_WinForms_Samples
{
    public partial class Form1 : Form
    {
        #region Variables
        private const String referencePath = "../../../Demo/";
        #endregion

        #region Initialization
        public Form1()
        {
            InitializeComponent();

            CreateLabelContent();
        }

        private void CreateLabelContent()
        {
            String content = "<div style=\"font:Verdana,9,r\"><p>   In this sample we are showing how to limit tab header width for longer titles and also we are presenting available display modes.</p><br></br>";
            content += "<p>   To cut the text length for we are using the <b>MaxTextSize</b> property from which width is used when content of tab header is horizontally oriented, and the height value when it is vertically oriented.</p><br></br>";
            content += "<p>   Additionaly there are three different display modes to choose from:<br></br>";
            content += "<b>      AutoSized</b> - tab header size is automatically resized to fully show its content which usually includes image and text<br></br>";
            content += "<b>      Compressed</b> - tab header shows image and text only for selected tab, all other tabs are shown with only an image<br></br>";
            content += "<b>      Justified</b> - tab header is resized to fully show its content and if there is some remaining space from tab strip, it is divided among visible tabs<br></br></p>";
            content += "<p><table width=\"100%\" cellpadding=\"5\"><tr height=\"5\"></tr>";
            content += "<tr><td width=\"70%\" style=\"textcolor:DarkRed;hovertextcolor:Red\"><a href=\"QuickStart.exe\" id=\"FILE\">Quick Start</a></td>";
            content += "<td width=\"30%\" style=\"align:middleright;textcolor:DarkRed;hovertextcolor:Red\"><a href=\"www.lidorsystems.com/support/articles/winforms/tabcontrol/\">More Info ...</a></td></tr></table></p>";
            content += "</div>";

            this.labelInfo.Content = content;
        }

        private void labelInfo_ContentObjectClicked(object sender, LidorSystems.IntegralUI.ObjectClickEventArgs e)
        {
            if (e.Object is LinkLabel)
            {
                String relativePath = (e.Object as LinkLabel).Links[0].LinkData.ToString();

                if (e.Key == "FILE")
                {
                    String appPath = Path.GetFullPath(Path.Combine(referencePath, relativePath));
                    if (File.Exists(appPath))
                        System.Diagnostics.Process.Start(appPath);
                    else if (File.Exists(relativePath))
                        System.Diagnostics.Process.Start(relativePath);
                }
                else
                    System.Diagnostics.Process.Start(relativePath);

            }
        }
        #endregion

        #region Functionality
        private void numWidth_ValueChanged(object sender, EventArgs e)
        {
            // Determines the maximum width and height of tab header
            this.tabControl1.MaxTextSize = new Size((int)numWidth.Value, (int)numWidth.Value);
        }

        private void Orientation_CheckedChanged(object sender, EventArgs e)
        {
            if (rbHorizontal.Checked)
                this.tabControl1.TabContentOrientation = Orientation.Horizontal;
            else if (rbVertical.Checked)
                this.tabControl1.TabContentOrientation = Orientation.Vertical;
        }

        private void btnApply_Click(object sender, EventArgs e)
        {
            // Tab headers are auto-sized to fit its content
            if (rbAutoSized.Checked)
                this.tabControl1.TabMode = LidorSystems.IntegralUI.Containers.TabMode.AutoSized;
            // Tab headers show full content only for selected tab, other tabs show only their image
            else if (rbCompressed.Checked)
                this.tabControl1.TabMode = LidorSystems.IntegralUI.Containers.TabMode.Compressed;
            // Tab headers are resized to fit their content size and if there is available space in tab strip
            // it is evenly duistributed among all visible tabs
            else if (rbJustified.Checked)
                this.tabControl1.TabMode = LidorSystems.IntegralUI.Containers.TabMode.Justified;
        }
        #endregion
    }
}